@@ -132,7 +132,7 @@
 #' @param .eval_plan Character string. The evaluation plan to use. One of 
 #'   "*sequential*", "*multicore*", or "*multisession*". In the two latter cases 
 #'   all available cores will be used. Defaults to "*sequential*".
-#' @param .filename Character string. The file name. Defaults to "results.xlsx".
+#' @param .filename Character string. The file name. 
 #' @param .first_resample A list containing the `.R` resamples based on the original
 #'   data obtained by resamplecSEMResults().
 #' @param .fit_measures Logical. (EXPERIMENTAL) Should additional fit measures 
@@ -141,6 +141,8 @@
 #'   already?. Defaults to `FALSE`.
 #' @param .full_output Logical. Should the full output of summarize be printed.
 #'   Defaults to `TRUE`.
+#' @param .graph_attrs Character string. Additional attributes that should be passed 
+#' to the DiagrammeR syntax, e.g., c("rankdir=LR", "ranksep=1.0"). Defaults to *c("rankdir=LR")*.
 #' @param .H The (N x J) matrix of construct scores.
 #' @param .handle_inadmissibles Character string. How should inadmissible results 
 #'   be treated? One of "*drop*", "*ignore*", or "*replace*". If "*drop*", all
@@ -213,7 +215,7 @@
 #'   compared across groups. Defaults to `NULL` in which case all weights, loadings and 
 #'   path coefficients of the originally specified model are compared.
 #' @param .path Character string. Path of the directory to save the file to. Defaults
-#'   to the current working directory.
+#'   to `NULL`.
 #' @param .path_coefficients List. A list that contains the resampled and the original 
 #' path coefficient estimates. Typically a part of a `cSEMResults_resampled` object.
 #' Defaults to `NULL`. 
@@ -222,7 +224,14 @@
 #'   "*fisher_transformed*", "*mean_arithmetic*", "*mean_geometric*", "*mean_harmonic*",
 #'   "*geo_of_harmonic*". Defaults to "*dist_squared_euclid*". 
 #'   Ignored if `.disattenuate = FALSE` or if `.approach_weights` is not PLS-PM.
+#' @param .plot_correlations Character string. Specify which correlations should be plotted, i.e., 
+#'   between the exogenous constructs (`exo`), between the exogenous constructs and the indicators (`all`),
+#'   or not at all (`none`). Defaults to `exo`.
+#' @param .plot_labels Logical. Whether to display edge labels. Defaults to TRUE.
 #' @param .plot_package Character string. Indicates which packages should be used for plotting.
+#' @param .plot_significances Logical. Should p-values in the form of stars be plotted? Defaults to `TRUE`.
+#' @param .plot_structural_model_only Logical. Should only the structural model, 
+#' i.e., the constructs and their relationships be plotted? Defaults to `FALSE`.
 #' @param .plot_type Character string. Indicates the type of plot that is produced.
 #' @param .PLS_ignore_structural_model Logical. Should the structural model be ignored
 #'   when calculating the inner weights of the PLS-PM algorithm? Defaults to `FALSE`.
@@ -313,6 +322,7 @@
 #' @param .testtype Character string. One of "*twosided*" (H1: The models do not 
 #'  perform equally in predicting indicators belonging to endogenous constructs)"
 #'  and *onesided*" (H1: Model 1 performs better in predicting indicators belonging 
+#' @param .title Character string. Title of an object. Defaults to *""*.
 #' @param .tolerance Double. The tolerance criterion for convergence. 
 #'   Defaults to `1e-05`.
 #' @param .treat_as_continuous Logical. Should the indicators for the benchmark predictions
@@ -397,21 +407,21 @@ NULL
 #' @keywords internal
 
 args_assess_dotdotdot <- function(
-  .absolute            = TRUE,
-  .alpha               = 0.05,
-  .ci                  = c("CI_standard_z", "CI_standard_t", "CI_percentile", 
-                           "CI_basic", "CI_bc", "CI_bca", "CI_t_interval"),
-  .closed_form_ci      = FALSE,
-  .handle_inadmissibles= c("drop", "ignore", "replace"),
-  .inference           = FALSE,
-  .null_model          = FALSE,
-  .R                   = 499,
-  .saturated           = FALSE,
-  .seed                = NULL,
-  .type_gfi            = c("ML", "GLS", "ULS"),
-  .type_vcv            = "indicator"
+    .absolute            = TRUE,
+    .alpha               = 0.05,
+    .ci                  = c("CI_standard_z", "CI_standard_t", "CI_percentile", 
+                             "CI_basic", "CI_bc", "CI_bca", "CI_t_interval"),
+    .closed_form_ci      = FALSE,
+    .handle_inadmissibles= c("drop", "ignore", "replace"),
+    .inference           = FALSE,
+    .null_model          = FALSE,
+    .R                   = 499,
+    .saturated           = FALSE,
+    .seed                = NULL,
+    .type_gfi            = c("ML", "GLS", "ULS"),
+    .type_vcv            = "indicator"
 ) {NULL}
-  
+
 #' Show argument defaults or candidates
 #'
 #' Show all arguments used by package functions including default or candidate
@@ -476,11 +486,12 @@ args_default <- function(.choices = FALSE) {
     .effect                  = NULL,
     .estimate_structural     = TRUE,
     .eval_plan               = c("sequential", "multicore","multisession"),
-    .filename                = "results.xlsx",
+    .filename                = NULL,
     .fit_measures            = FALSE,
     .first_resample          = NULL,
     .force                   = FALSE,
     .full_output             = TRUE,
+    .graph_attrs             = c("rankdir=LR"),
     .handle_inadmissibles    = c("drop", "ignore", "replace"),
     .H                       = NULL,
     .id                      = NULL,
@@ -511,7 +522,11 @@ args_default <- function(.choices = FALSE) {
     .parameters_to_compare   = NULL,
     .path                    = NULL,
     .path_coefficients       = NULL,
+    .plot_correlations       = c("exo", "none", "all"),
+    .plot_labels             = TRUE,
     .plot_package            = NULL,
+    .plot_significances      = TRUE,
+    .plot_structural_model_only = FALSE,
     .plot_type               = NULL,
     .probs                   = NULL,
     .PLS_approach_cf         = c("dist_squared_euclid", "dist_euclid_weighted", 
@@ -560,6 +575,7 @@ args_default <- function(.choices = FALSE) {
     .steps_mod               = NULL,
     .terms                   = NULL,
     .test_data               = NULL,
+    .title                   = "",
     .tolerance               = 1e-05,
     .treat_as_continuous     = TRUE,
     .type_gfi                = c("ML", "GLS", "ULS"),
@@ -581,11 +597,11 @@ args_default <- function(.choices = FALSE) {
     .y                       = NULL,
     .z                       = NULL
   )
-
+  
   if(!.choices) {
     args <- lapply(args, function(x) eval(x)[1])
   }
-    
+  
   args_sorted <- args[sort(names(args))]
   
   return(args_sorted)
@@ -625,13 +641,13 @@ handleArgs <- function(.args_used) {
   # choices_logical <- Filter(function(x) any(is.logical(x)), args_default(.choices = TRUE))
   # choices_numeric <- Filter(function(x) any(is.numeric(x)), args_default(.choices = TRUE))
   choices_character <- Filter(function(x) any(is.character(x)), args_default(.choices = TRUE))
-
+  
   character_args <- intersect(names(choices_character), args_used_names)
   x <- Map(function(x, y) x %in% y, 
-      x = .args_used[character_args], 
-      y = choices_character[character_args]
-      )
-
+           x = .args_used[character_args], 
+           y = choices_character[character_args]
+  )
+  
   lapply(seq_along(x), function(i) {
     if(isFALSE(x[[i]])) {
       n <- names(x[i])
@@ -641,7 +657,7 @@ handleArgs <- function(.args_used) {
            "Choices are: ", paste0("`", a[-length(a)],"`", collapse = ", "), 
            " or " , paste0("`", a[length(a)], "`"), call. = FALSE)
     }
-
+    
   })
   ## Replace all arguments that were changed or explicitly given and keep
   #  the default values for the others
